@@ -19,7 +19,7 @@ EOF
 __PACKAGE__->attr('conf_file');
 __PACKAGE__->attr('conf');
 
-our $VERSION = "0.02";
+our $VERSION = "0.03";
 
 
 sub run {
@@ -131,6 +131,14 @@ NOTFOUND
             $self->render_to_file('package', $dest_file, $app_klass, $dest_lang,
                 \%lexicon);
 
+            if ( defined $conf->{json} && $conf->{json} == 1 ){
+                my $dest_json = $app->home->rel_file("public/${dest_lang}.json");
+
+                # Output json
+                $self->render_to_file('json', $dest_json, $app_klass, $dest_lang,
+                    \%lexicon);
+            }
+
         }
 
         my %utf8_orglex = map { $_ => (utf8::is_utf8 ($orglex{$_})) ? $orglex{$_} : decode("utf8", $orglex{$_})} keys %orglex;
@@ -138,6 +146,16 @@ NOTFOUND
         $self->render_to_file('package', $src_file, $app_klass, $src_lang,
                 \%utf8_orglex);
 
+        if ( defined $conf->{json} && $conf->{json} == 1 ){
+
+            my $dest_json = $app->home->rel_file("public/${src_lang}.json");
+
+            # Output json
+            $self->render_to_file('json', $dest_json, $app_klass, $src_lang,
+                \%utf8_orglex);
+
+        }
+
     }
     else{
 
@@ -146,13 +164,34 @@ NOTFOUND
             my $dest_file = $app->home->rel_file("lib/$app_class/I18N/${dest_lang}.pm");
 
             my %lexicon = map { $_ => $self->translate( $src_lang, $dest_lang, $srclex{$_}) } keys %srclex;
-            
 
             # Output lexem
             $self->render_to_file('package', $dest_file, $app_klass, $dest_lang,
                 \%lexicon);
 
+            if ( defined $conf->{json} && $conf->{json} == 1 ){
+
+                my $dest_json = $app->home->rel_file("public/${dest_lang}.json");
+
+                # Output json
+                $self->render_to_file('json', $dest_json, $app_klass, $dest_lang,
+                    \%lexicon);
+            }
+
         }
+
+        if ( defined $conf->{json} && $conf->{json} == 1 ){
+
+            my $dest_json = $app->home->rel_file("public/${src_lang}.json");
+
+            my %utf8_srclex = map { $_ => (utf8::is_utf8 ($srclex{$_})) ? $srclex{$_} : decode("utf8", $srclex{$_})} keys %srclex;
+
+            # Output json
+            $self->render_to_file('json', $dest_json, $app_klass, $src_lang,
+                \%utf8_srclex);
+
+        }
+
     }
 
 }
@@ -218,6 +257,28 @@ our %Lexicon = (
 
 1;
 
+@@ json
+% my ($app_class, $language, $lexicon) = @_;
+{
+% my $first = 0;
+% foreach my $lexem (sort keys %$lexicon) {
+    %= ($first++ == 0)? "" : "," 
+    % my $data = $lexicon->{$lexem} || '';
+    % $lexem=~s/"/\\"/g;
+    % utf8::encode $data;
+    % $data =~s/"/\\"/g;
+    % if( $data =~ s/\n/\\n/g ){
+    %   $data = '"' . $data . '"';
+    % } else {
+    %   $data = "\"${data}\"";
+    % }
+    % unless ($lexem=~s/\n/\\n/g) {
+    "<%= $lexem %>" : <%= $data %>
+    % } else {
+    "<%= $lexem %>" : <%= $data %>
+    % };
+% }
+}
 __END__
 
 =encoding utf-8
@@ -252,11 +313,13 @@ Lingua::Translate. So you can customize translation service.
 It is not convenient every time all the lexicons are translated.
 Write the lexicon in the package Myapp::I18N::org, and generate only difference parts.
 
+Support front end JavaScript lexicon library l10n.js <https://github.com/eligrey/l10n.js/>
+If you want to generate a lexicon file of l10n.js , please attach a json option in the configuration file.
+
 =head1 CONFIGURATION
 
 Create config file lexicont.conf on your project home directory.
 
-
 #InterTran
 
 {
@@ -266,6 +329,8 @@ Create config file lexicont.conf on your project home directory.
     sleep => 5,
 }
 
+sleep parameter is for access interval.
+
 #Bing
 
 {
@@ -286,7 +351,15 @@ Create config file lexicont.conf on your project home directory.
     }
 }
 
+#Google with JSON lexicon output
 
+{
+    lingua_translate => {
+        back_end => "Google",
+        api_key => "YOUR_API_KEY", 
+    },
+    json => 1
+}
 
 
 =head1 LICENSE
